<?php

namespace plugin\ticket\controller\api\auth;


use plugin\ticket\controller\api\Auth;
use plugin\ticket\model\TicketUserShare;

/**
 * 用户随手拍小程序接口
 */
class UserShare extends Auth
{
    public function index()
    {
        $pageData = TicketUserShare::query()->where(['user_id'=>$this->usid])->order('id', 'desc')->paginate();
        $this->success('获取用户随手拍列表', $pageData);
    }

    public function info()
    {
        $data = $this->_vali([
            'id.require' => 'ID不能为空',
        ]);
        $info = TicketUserShare::query()->with(['logs'])->where(['user_id'=>$this->usid])->where('id', '=', $data['id'])->findOrEmpty();
        if ($info->isEmpty()) $this->error('数据不存在');
        $this->success('获取用户随手拍详情', $info);
    }

    public function add()
    {
        $data = $this->_vali([
            'title.default' => '用户随手拍',
            'content.require' => '内容不能为空',
            'imgs.default' => '',
            'type_id.require' => '类型不能为空',
            'contact_phone.require' => '手机号不能为空',
            'ticket_region.require' => '地址不能为空',
            'ticket_address.require' => '地址不能为空',
            'contact_name.default' => $this->account->user() ? $this->account->user()['nickname'] : '用户',
        ]);
        $data['user_id'] = $this->usid;
        $id = TicketUserShare::query()->insert($data, true);
        $this->success('添加随手拍成功', $id);
    }

    private static $lbs_key = "JJWBZ-YLGLA-LCIKH-CH6C7-VVXC2-J5BEF";

    public function query_address()
    {
        $data = $this->_vali([
            'lat.require' => '纬度不能为空',
            'lng.require' => '经度不能为空',
        ]);
        $url = "https://apis.map.qq.com/ws/geocoder/v1/?location={$data['lat']},{$data['lng']}&key=".self::$lbs_key;
        $result = http_get($url);
        $result = json_decode($result, true);
        if ($result['status'] == 0) {
            // 只支持广安市广安区免省市区
            $address = $result['result']['address'];
            $address_component = $result['result']['address_component'];
            if (isset($address_component['province']) && $address_component['province'] != '四川省') {
                $address = $result['result']['address'];
            } else {
                if (isset($address_component['city']) && $address_component['city'] != '广安市') {
                    $address = $result['result']['address'];
                } else {
                    if (isset($address_component['district']) && $address_component['district'] != '广安区') {
                        $address = $address_component['district'] + $address_component['street'] + $address_component['street_number'];
                    } else {
                        $address = $address_component['street'] + $address_component['street_number'];
                    }
                }
            }
            $this->success('查询成功', $address);
        } else {
            $this->error('查询失败');
        }
    }
}